//**************************************************************
// LiteCAD Application Demo
// Resources Unit
// harry200@gmail.com
//**************************************************************

unit res;

interface

uses
  Windows, SysUtils, System.StrUtils, System.Classes,
  main, litecad;

const

  AppNameLC        = 'LiteCADapp' {$IFDEF WIN64}+'(x64)'{$ENDIF};
  AppVendor        = 'by Harry, ';
  AppBetaVersion   = '(beta)';
  AppSite          = 'https://kolbasoft.com';

  NewFNameLCD      = 'new.lcd';

resourcestring

  LCADMsgTitle          = 'LiteCAD';
  LCADHelpFile          = 'LiteCAD.chm';
  LCADIniFile           = 'Config/Litecad.ini';
  LCADFNameNew          = 'drawing';
  LCADLangRU            = 'LC_russian.lng';
  LCADLangEN            = 'LC_original.lng';
  LCADPluginCFG         = 'Litecad.plc';
  LCADLangDefault       = 'EN';
  LangRU                = 'RU';

  {
    User's select messages in LiteCAD actions
    To sync with array MsgShowPoint by element count
    Used to LcEventProc
  }

  MsgSelDefault         = 'Select point';
  MsgSelPline           = 'Select polyline';

  { Info messages }

  MsgInfo               = 'InfoMessage';

  { Error messages }

  MsgErrOpenFile        = 'Error open file: %s';
  MsgErrNoSupport       = '%s Not support';

  { Ask messages }

  MsgAskSaveChanges     = 'Save changes: %s ?';

  { Update App messages }

  MsgUpdateAvailable    = 'App update available: %s'#13#10'Download and update?';
  MsgUpdateNotNeed      = 'App is up to date';
  MsgUpdateNotAvailable = 'Update is not available! Check Internet connection';
  MsgUpdateOK           = 'Success, reload App!';

  { Dialogs title }

  MsgOpenDefaultTitle   = 'Open File...';
  MsgSaveDialogTitle    = 'Save File as...';

  { Status panel }

  Caption_XY            = 'X: %.4f Y: %.4f';
  Caption_PixelSize     = 'Pixel size: %.4f mm';
  Caption_VisibleArea   = 'Visible area: L= %.2f B=%.2f R=%.2f T=%.2f W=%.2f H=%.2f';

  const

    DEFAULT_LANG     = 'EN'; // Default Interface Language is English
    DEFAULT_WNDSTYLE = 768;  // 512, Specifies the style of the window being created LC_WS_RULERS or LC_WS_VIEWTABS
    DEFAULT_OSNAP    = 46;   // Object snap mode LC_OSNAP_ENDPOINT or LC_OSNAP_MIDPOINT or LC_OSNAP_CENTER or LC_OSNAP_INTER
    DEFAULT_GRIDDX   = 5;    // Distance between vertical grid lines
    DEFAULT_GRIDDY   = 5;    // Distance between horizontal grid lines

    OpenDialogFilter = 'LiteCAD(*.lcd)|*.lcd|AutoCAD drawing(*.dwg,*.dxf)|*.dwg;*.dxf|Adobe Illustrator(*.ai)|*.ai|HP-GL/2 file(*.plt)|*.plt|Scalable Vector Graphics file(*.svg)|*.svg|VeCAD drawing(*.vec)|*.vec|All supported files|*.lcd;*.dwg;*.dxf;*.ai;*.plt;*.svg;*.vec';
    FExtensions:       array[0..6] of string = ('.lcd','.dwg','.dxf','.ai','.plt','.svg','.vec');

    // Help topics

    HelpTopic_WhatNew     = 0;

    // User`s messages array
    MsgShowPoint: array[0..1] of String = (MsgSelDefault,
                                           MsgSelPline
                                           );

  procedure SetFormCaption;
  function  GetNewFileName: String;
  function  GetAppVersion(const sAppNamePath: TFileName): String;
  function  GetAppName: String;
  function  GetAppBeta: String;
  function  GetAppVend: String;
  function  PathApp: String;
  function  GetMsgIndex(msg: String): Integer;
  function  GetFileExt(FName: String): Integer;

implementation

procedure SetFormCaption;
begin
  FormMain.Caption:=AppNameLC+' '+GetAppVersion(Paramstr(0))+GetAppBeta;
end;

// Generate new file name
function GetNewFileName: String;
begin
  Inc(CounterNewFile);
  Result:=LCADFNameNew + IntToStr(CounterNewFile)
end;

// Get App version info
function GetAppVersion(const sAppNamePath: TFileName): String;
var
  VerSize:     Integer;
  VerBuf:      PChar;
  VerBufValue: Pointer;
  VerHandle:   Cardinal;
  VerBufLen:   Cardinal;
  VerKey:      String;

  function GetInfo(const aKey: String): String;
  begin
    VerKey := Format('\StringFileInfo\%.4x%.4x\%s', [LoWord(Integer(VerBufValue^)), HiWord(Integer(VerBufValue^)), aKey]);
    if VerQueryValue(VerBuf, PChar(VerKey), VerBufValue, VerBufLen)
      then Result:=StrPas(PChar(VerBufValue))
      else Result:=EmptyStr
  end;

  function QueryValue(const aValue: String): String;
  begin
    if GetFileVersionInfo(PChar(sAppNamePath),VerHandle,VerSize,VerBuf)
      and VerQueryValue(VerBuf,'\VarFileInfo\Translation',VerBufValue,VerBufLen)
      then Result:=GetInfo(aValue)
      else Result:=EmptyStr
  end;

begin
  Result:=EmptyStr;
  begin
    VerSize:=GetFileVersionInfoSize(PChar(sAppNamePath), VerHandle);
    if VerSize > 0 then
      begin
        VerBuf:=AllocMem(VerSize);
        try
          Result:=QueryValue('FileVersion');
        finally
          FreeMem(VerBuf, VerSize);
        end
      end
  end
end;

function GetAppName: String;
begin
  Result:={$IFDEF LITECAD}AppNameLC{$ELSE}EmptyStr{$ENDIF LITECAD}
end;

function GetAppBeta: String;
begin
  Result:={$IFDEF BETAVERSION}AppBetaVersion{$ELSE}EmptyStr{$ENDIF BETAVERSION}
end;

function GetAppVend: String;
begin
   Result:=AppVendor+IntToStr(CurrentYear)
end;

// Get message index
function GetMsgIndex(msg: String): Integer;
  var i: Integer;
begin
  Result:=0;
  for i:=Low(MsgShowPoint) to High(MsgShowPoint) do
    if msg=MsgShowPoint[i] then
      begin
        Result:=i;
        break
      end
end;

// Get App path
function PathApp: String;
begin
  Result:=ExtractFilePath(ParamStr(0));
end;

// Get file extension index
function GetFileExt(FName: String): Integer;
begin
  Result:=IndexText(ExtractFileExt(FName),FExtensions)
end;

end.
